@@ -59,7 +59,7 @@ class BaseConnector(object):
     :param conn_timeout: (optional) Connect timeout.
     :param keepalive_timeout: (optional) Keep-alive timeout.
     :param bool share_cookies: Set to True to keep cookies between requests.
-    :param bool force_close: Set to True to froce close and do reconnect
+    :param bool force_close: Set to True to force close and do reconnect
         after each request (and between redirects).
     :param loop: Optional event loop.
     """
@@ -128,7 +128,7 @@ class BaseConnector(object):
     @staticmethod
     def _do_close(conns):
         for key, data in conns.items():
-            for transport, proto, td in data:
+            for transport, proto, t0 in data:
                 transport.close()
 
         conns.clear()
@@ -199,7 +199,13 @@ class BaseConnector(object):
 
         reader = protocol.reader
         if should_close or (reader.output and not reader.output.at_eof()):
-            self._conns.pop(key, None)
+            conns = self._conns.get(key)
+            if conns is not None and len(conns) == 0:
+                # Issue #253: An empty array will eventually be
+                # removed by cleanup, but it's better to pop straight
+                # away, because cleanup might not get called (e.g. if
+                # keepalive is False).
+                self._conns.pop(key, None)
             transport.close()
         else:
             conns = self._conns.get(key)
@@ -223,7 +229,7 @@ class TCPConnector(BaseConnector):
 
     :param bool verify_ssl: Set to True to check ssl certifications.
     :param bool resolve: Set to True to do DNS lookup for host name.
-    :param familiy: socket address family
+    :param family: socket address family
     :param args: see :class:`BaseConnector`
     :param kwargs: see :class:`BaseConnector`
     """
