@@ -10,7 +10,7 @@ import urllib.parse
 from collections import namedtuple
 from wsgiref.handlers import format_date_time
 
-from . import multidict
+from . import hdrs, multidict
 
 
 class BasicAuth(namedtuple('BasicAuth', ['login', 'password', 'encoding'])):
@@ -68,7 +68,7 @@ class FormData:
         if isinstance(value, io.IOBase):
             self._is_multipart = True
 
-        type_options = multidict.MutableMultiDict({'name': name})
+        type_options = multidict.MultiDict({'name': name})
         if filename is None and isinstance(value, io.IOBase):
             filename = guess_filename(value, name)
         if filename is not None:
@@ -77,10 +77,10 @@ class FormData:
 
         headers = {}
         if content_type is not None:
-            headers['Content-Type'] = content_type
+            headers[hdrs.CONTENT_TYPE] = content_type
             self._is_multipart = True
         if content_transfer_encoding is not None:
-            headers['Content-Transfer-Encoding'] = content_transfer_encoding
+            headers[hdrs.CONTENT_TRANSFER_ENCODING] = content_transfer_encoding
             self._is_multipart = True
             supported_tranfer_encoding = {
                 'base64': binascii.b2a_base64,
@@ -102,8 +102,10 @@ class FormData:
                 k = guess_filename(rec, 'unknown')
                 self.add_field(k, rec)
 
-            elif isinstance(rec, multidict.MultiDict):
-                to_add.extend(rec.items(getall=True))
+            elif isinstance(rec,
+                            (multidict.MultiDictProxy,
+                             multidict.MultiDict)):
+                to_add.extend(rec.items())
 
             elif isinstance(rec, (list, tuple)) and len(rec) == 2:
                 k, fp = rec
@@ -117,7 +119,7 @@ class FormData:
     def _gen_form_urlencoded(self, encoding):
         # form data (x-www-form-urlencoded)
         data = []
-        for type_options, headers, value in self._fields:
+        for type_options, _, value in self._fields:
             data.append((type_options['name'], value))
 
         data = urllib.parse.urlencode(data, doseq=True)
@@ -269,8 +271,8 @@ def atoms(message, environ, response, transport, request_time):
         'r': r,
         's': str(getattr(response, 'status', '')),
         'b': str(getattr(response, 'output_length', '')),
-        'f': headers.get('REFERER', '-'),
-        'a': headers.get('USER-AGENT', '-'),
+        'f': headers.get(hdrs.REFERER, '-'),
+        'a': headers.get(hdrs.USER_AGENT, '-'),
         'T': str(int(request_time)),
         'D': str(request_time).split('.', 1)[-1][:5],
         'p': "<%s>" % os.getpid()
