@@ -112,13 +112,13 @@ def parse_message(buf):
         elif payload:
             raise WebSocketError(
                 'Invalid close frame: {} {} {!r}'.format(fin, opcode, payload))
-        return Message(OPCODE_CLOSE, '', '')
+        return Message(OPCODE_CLOSE, 0, '')
 
     elif opcode == OPCODE_PING:
-        return Message(OPCODE_PING, '', '')
+        return Message(OPCODE_PING, payload, '')
 
     elif opcode == OPCODE_PONG:
-        return Message(OPCODE_PONG, '', '')
+        return Message(OPCODE_PONG, payload, '')
 
     elif opcode not in (OPCODE_TEXT, OPCODE_BINARY):
         raise WebSocketError("Unexpected opcode={!r}".format(opcode))
@@ -160,13 +160,17 @@ class WebSocketWriter:
 
         self.writer.write(header + message)
 
-    def pong(self):
+    def pong(self, message=b''):
         """Send pong message."""
-        self._send_frame(b'', OPCODE_PONG)
+        if isinstance(message, str):
+            message = message.encode('utf-8')
+        self._send_frame(message, OPCODE_PONG)
 
-    def ping(self):
+    def ping(self, message=b''):
         """Send ping message."""
-        self._send_frame(b'', OPCODE_PING)
+        if isinstance(message, str):
+            message = message.encode('utf-8')
+        self._send_frame(message, OPCODE_PING)
 
     def send(self, message, binary=False):
         """Send a frame over the websocket with message as its payload."""
@@ -213,11 +217,11 @@ def do_handshake(method, headers, transport, protocols=()):
     # find common sub-protocol between client and server
     protocol = None
     if 'SEC-WEBSOCKET-PROTOCOL' in headers:
-        req_protocols = {str(proto.strip()) for proto in
-                         headers['SEC-WEBSOCKET-PROTOCOL'].split(',')}
+        req_protocols = [str(proto.strip()) for proto in
+                         headers['SEC-WEBSOCKET-PROTOCOL'].split(',')]
 
-        for proto in protocols:
-            if proto in req_protocols:
+        for proto in req_protocols:
+            if proto in protocols:
                 protocol = proto
                 break
         else:
@@ -230,7 +234,8 @@ def do_handshake(method, headers, transport, protocols=()):
     version = headers.get('SEC-WEBSOCKET-VERSION')
     if version not in ('13', '8', '7'):
         raise errors.HttpBadRequest(
-            message='Unsupported version: {}'.format(version))
+            message='Unsupported version: {}'.format(version),
+            headers=(('Sec-WebSocket-Version', '13', '8', '7'),))
 
     # check client handshake for validity
     key = headers.get('SEC-WEBSOCKET-KEY')
