@@ -8,7 +8,7 @@ import unittest.mock
 import aiohttp
 from aiohttp import errors
 from aiohttp import protocol
-from aiohttp import multidict
+from aiohttp import CIMultiDict
 
 
 class ParseHeadersTests(unittest.TestCase):
@@ -36,7 +36,7 @@ class ParseHeadersTests(unittest.TestCase):
 
         headers, close, compression = self.parser.parse_headers(hdrs)
 
-        self.assertEqual(list(headers.items(getall=True)),
+        self.assertEqual(list(headers.items()),
                          [('SET-COOKIE', 'c1=cookie1'),
                           ('SET-COOKIE', 'c2=cookie2')])
         self.assertIsNone(close)
@@ -86,13 +86,13 @@ class ParseHeadersTests(unittest.TestCase):
         self.assertIn("limit request headers fields size", str(cm.exception))
 
     def test_invalid_header(self):
-        with self.assertRaisesRegexp(
+        with self.assertRaisesRegex(
                 errors.InvalidHeader,
                 "(400, message='Invalid HTTP Header: test line)"):
             self.parser.parse_headers(['', 'test line\r\n', '\r\n'])
 
     def test_invalid_name(self):
-        with self.assertRaisesRegexp(
+        with self.assertRaisesRegex(
                 errors.InvalidHeader,
                 "(400, message='Invalid HTTP Header: TEST..)"):
             self.parser.parse_headers(['', 'test[]: line\r\n', '\r\n'])
@@ -243,7 +243,8 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_length_broken(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('CONTENT-LENGTH', 'qwe')]), None, None)
+            CIMultiDict([('CONTENT-LENGTH', 'qwe')]),
+            None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
@@ -252,7 +253,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_length_wrong(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('CONTENT-LENGTH', '-1')]), None, None)
+            CIMultiDict([('CONTENT-LENGTH', '-1')]), None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
@@ -261,7 +262,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_length(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('CONTENT-LENGTH', '2')]), None, None)
+            CIMultiDict([('CONTENT-LENGTH', '2')]), None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
@@ -276,7 +277,7 @@ class ParsePayloadTests(unittest.TestCase):
 
     def test_http_payload_parser_no_length(self):
         msg = protocol.RawRequestMessage(
-            'GET', '/', (1, 1), multidict.MultiDict(), None, None)
+            'GET', '/', (1, 1), CIMultiDict(), None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg, readall=False)(out, buf)
@@ -290,7 +291,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_deflate(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('CONTENT-LENGTH', len(self._COMPRESSED))]),
+            CIMultiDict([('CONTENT-LENGTH', len(self._COMPRESSED))]),
             None, 'deflate')
 
         out = aiohttp.FlowControlDataQueue(self.stream)
@@ -303,7 +304,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_deflate_disabled(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('CONTENT-LENGTH', len(self._COMPRESSED))]),
+            CIMultiDict([('CONTENT-LENGTH', len(self._COMPRESSED))]),
             None, 'deflate')
 
         out = aiohttp.FlowControlDataQueue(self.stream)
@@ -316,7 +317,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_websocket(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('SEC-WEBSOCKET-KEY1', '13')]), None, None)
+            CIMultiDict([('SEC-WEBSOCKET-KEY1', '13')]), None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
@@ -327,7 +328,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_chunked(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('TRANSFER-ENCODING', 'chunked')]),
+            CIMultiDict([('TRANSFER-ENCODING', 'chunked')]),
             None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
@@ -339,7 +340,7 @@ class ParsePayloadTests(unittest.TestCase):
 
     def test_http_payload_parser_eof(self):
         msg = protocol.RawRequestMessage(
-            'GET', '/', (1, 1), multidict.MultiDict(), None, None)
+            'GET', '/', (1, 1), CIMultiDict(), None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg, readall=True)(out, buf)
@@ -352,7 +353,7 @@ class ParsePayloadTests(unittest.TestCase):
     def test_http_payload_parser_length_zero(self):
         msg = protocol.RawRequestMessage(
             'GET', '/', (1, 1),
-            multidict.MultiDict([('CONTENT-LENGTH', '0')]), None, None)
+            CIMultiDict([('CONTENT-LENGTH', '0')]), None, None)
         out = aiohttp.FlowControlDataQueue(self.stream)
         buf = aiohttp.ParserBuffer()
         p = protocol.HttpPayloadParser(msg)(out, buf)
@@ -388,7 +389,7 @@ class ParseRequestTests(unittest.TestCase):
             pass
         result = out._buffer[0]
         self.assertEqual(
-            ('GET', '/path', (1, 1), multidict.MultiDict(), False, None),
+            ('GET', '/path', (1, 1), CIMultiDict(), False, None),
             result)
 
     def test_http_request_parser_utf8(self):
@@ -404,7 +405,7 @@ class ParseRequestTests(unittest.TestCase):
         result = out._buffer[0]
         self.assertEqual(
             ('GET', '/path', (1, 1),
-             multidict.MultiDict([('X-TEST', 'тест')]), False, None),
+             CIMultiDict([('X-TEST', 'тест')]), False, None),
             result)
 
     def test_http_request_parser_eof(self):
@@ -430,7 +431,7 @@ class ParseRequestTests(unittest.TestCase):
         except StopIteration:
             pass
         self.assertEqual(
-            ('GET', '//path', (1, 1), multidict.MultiDict(), False, None),
+            ('GET', '//path', (1, 1), CIMultiDict(), False, None),
             out._buffer[0])
 
     def test_http_request_parser_bad_status_line(self):
@@ -480,7 +481,7 @@ class ParseResponseTests(unittest.TestCase):
         self.assertEqual(v, (1, 1))
         self.assertEqual(s, 200)
         self.assertEqual(r, 'Ok')
-        self.assertEqual(h, multidict.MultiDict([('X-TEST', 'тест')]))
+        self.assertEqual(h, CIMultiDict([('X-TEST', 'тест')]))
 
     def test_http_response_parser_bad_status_line(self):
         out = aiohttp.FlowControlDataQueue(self.stream)
